/*!
 * jQuery UI Touch Punch 0.2.2
 *
 * Copyright 2011, Dave Furfero
 * Dual licensed under the MIT or GPL Version 2 licenses.
 *
 * Depends:
 *  jquery.ui.widget.js
 *  jquery.ui.mouse.js
 */
(function ($) {
	
  // Detect touch support
  $.support.touch = 'ontouchend' in document;

  // Ignore browsers without touch support
  if (!$.support.touch) {
    return;
  }

  var mouseProto = $.ui.mouse.prototype,
      _mouseInit = mouseProto._mouseInit,
      touchHandled;

  /**
   * Simulate a mouse event based on a corresponding touch event
   * @param {Object} event A touch event
   * @param {String} simulatedType The corresponding mouse event
   */
  function simulateMouseEvent (event, simulatedType) {

    // Ignore multi-touch events
    if (event.originalEvent.touches.length > 1) {
      return;
    }

    event.preventDefault();

    var touch = event.originalEvent.changedTouches[0],
        simulatedEvent = document.createEvent('MouseEvents');
    
    // Initialize the simulated mouse event using the touch event's coordinates
    simulatedEvent.initMouseEvent(
      simulatedType,    // type
      true,             // bubbles                    
      true,             // cancelable                 
      window,           // view                       
      1,                // detail                     
      touch.screenX,    // screenX                    
      touch.screenY,    // screenY                    
      touch.clientX,    // clientX                    
      touch.clientY,    // clientY                    
      false,            // ctrlKey                    
      false,            // altKey                     
      false,            // shiftKey                   
      false,            // metaKey                    
      0,                // button                     
      null              // relatedTarget              
    );

    // Dispatch the simulated event to the target element
    event.target.dispatchEvent(simulatedEvent);
  }

  /**
   * Handle the jQuery UI widget's touchstart events
   * @param {Object} event The widget element's touchstart event
   */
  mouseProto._touchStart = function (event) {

    var self = this;

    // Ignore the event if another widget is already being handled
    if (touchHandled || !self._mouseCapture(event.originalEvent.changedTouches[0])) {
      return;
    }

    // Set the flag to prevent other widgets from inheriting the touch event
    touchHandled = true;

    // Track movement to determine if interaction was a click
    self._touchMoved = false;

    // Simulate the mouseover event
    simulateMouseEvent(event, 'mouseover');

    // Simulate the mousemove event
    simulateMouseEvent(event, 'mousemove');

    // Simulate the mousedown event
    simulateMouseEvent(event, 'mousedown');
  };

  /**
   * Handle the jQuery UI widget's touchmove events
   * @param {Object} event The document's touchmove event
   */
  mouseProto._touchMove = function (event) {

    // Ignore event if not handled
    if (!touchHandled) {
      return;
    }

    // Interaction was not a click
    this._touchMoved = true;

    // Simulate the mousemove event
    simulateMouseEvent(event, 'mousemove');
  };

  /**
   * Handle the jQuery UI widget's touchend events
   * @param {Object} event The document's touchend event
   */
  mouseProto._touchEnd = function (event) {

    // Ignore event if not handled
    if (!touchHandled) {
      return;
    }

    // Simulate the mouseup event
    simulateMouseEvent(event, 'mouseup');

    // Simulate the mouseout event
    simulateMouseEvent(event, 'mouseout');

    // If the touch interaction did not move, it should trigger a click
    if (!this._touchMoved) {

      // Simulate the click event
      simulateMouseEvent(event, 'click');
    }

    // Unset the flag to allow other widgets to inherit the touch event
    touchHandled = false;
  };

  /**
   * A duck punch of the $.ui.mouse _mouseInit method to support touch events.
   * This method extends the widget with bound touch event handlers that
   * translate touch events to mouse events and pass them to the widget's
   * original mouse event handling methods.
   */
  mouseProto._mouseInit = function () {
    
    var self = this;

    // Delegate the touch handlers to the widget's element
    self.element
      .bind('touchstart', $.proxy(self, '_touchStart'))
      .bind('touchmove', $.proxy(self, '_touchMove'))
      .bind('touchend', $.proxy(self, '_touchEnd'));

    // Call the original $.ui.mouse init method
    _mouseInit.call(self);
  };

})(jQuery);

jQuery( document ).ready( function( $ ) { 
	'use strict';

	// loop through each widget
	$( '.sp-woocommerce-dropshop-container' ).each( function() {
		var mainContainer = $( this ),
			settings = $.parseJSON( $( '.sp-woocommerce-dropshop-settings', mainContainer ).val() );

		// declared namespace to prevent conflict
		$.woocommerce_dropshop_scripts = {
			
			init: function() {
				var autoHideTimer,
					followTimer;

				function setFollow() {
					var time = 6000;
					
					// first check if cart follow is set and that it is vertical orientation
					if ( settings.cart_follow === 'follow' && settings.orientation === 'vertical' ) {					
						// first clear the timer
						window.clearTimeout( followTimer );

						// set the timer for the cart and slide back when expired
						followTimer = window.setTimeout( function() { mainContainer.css( 'position', 'relative' ).css( 'top', 'auto' ); }, time );
					}
				}

				function clearFollow() {
					// first check if cart follow is set and that it is vertical orientation
					if ( settings.cart_follow === 'follow' && settings.orientation === 'vertical' ) {					
						window.clearTimeout( followTimer );
					}
				}

				function setAutoHide() {
					var time = parseInt( settings.autohide_duration, 10 ) * 1000;

					// if autohide is on
					if ( settings.autohide === 'on' ) {
						// first clear the timer
						window.clearTimeout( autoHideTimer );						
					
						// set the timer for the cart and slide back when expired
						autoHideTimer = window.setTimeout( function() { mainContainer.stop().animate( {bottom: '-105px'}, 500, 'swing' ); }, time );	
					}
				}

				setAutoHide();

				function clearAutoHide() {
					// if autohide is on
					if ( settings.autohide === 'on' ) {				
						window.clearTimeout( autoHideTimer );
					}
				}
				
				// check if custom is on first
				if ( settings.custom === 'on' ) { 
					// check if background color is set
					if ( settings.btn_bg_color_hv.length && settings.btn_bg_color_hv !== '' && settings.btn_bg_color.length && settings.btn_bg_color !== '' ) { 
						var colorHover = settings.btn_bg_color_hv,
							color = settings.btn_bg_color;
						
						// apply the custom hover color set in the options to the checkout button background
						$( 'a.sp-woocommerce-dropshop-checkout-button, a.sp-woocommerce-dropshop-viewcart-button', mainContainer ).hover(function() { 
							$( this ).css({'background-image' : 'none', 'background-color' : colorHover});	
						}, function() {
							$( this ).css({'background-image' : 'none', 'background-color' : color});
						} );
					}
					
					// check if text color is set
					if ( settings.text_color.length && settings.text_color !== '' ) { 
						var title = $( ' h3.widget-title', mainContainer ),
							empty = $( 'p.sp-woocommerce-dropshop-cart-empty', mainContainer ),
							total = $( 'p.sp-woocommerce-dropshop-cart-total', mainContainer );
						
						title.css( 'color', settings.text_color );
						empty.css( 'color', settings.text_color );
						total.css( 'color', settings.text_color );	
					}
				}

				// toggle horizontal position cart open close
				$( 'span.sp-woocommerce-dropshop-tab', mainContainer ).click( function() {
					// check current position
					if ( parseInt( mainContainer.css( 'bottom' ), 10 ) === 0 ) {		
						mainContainer.stop().animate( {bottom: '-105px'}, 500, 'swing' );
						
						// clear the timer when closed
						clearAutoHide();					
					} else {
						mainContainer.stop().animate( {bottom: '0'}, 500, 'swing' );

						setAutoHide();
					}
				});

				// grab saved settings
				var visible = parseInt( settings.visible, 10 ),
					orientation = settings.orientation,
					speed = parseInt( settings.speed, 10 ),
					scrollBy = parseInt( settings.scrollby, 10 );
					
				// set a default if not set
				if ( visible.length === 0 ) {
					visible = 3;
				}
					
				// set a default if not set
				if ( orientation.length === 0 ) {
					orientation = 'down';
				} else if ( orientation === 'vertical' ) {
					orientation = 'down';
				} else if ( orientation === 'horizontal' ) {
					orientation = 'left';	
				}
				
				// set a default if not set
				if ( speed.length === 0 ) {
					speed = 400;
				}
				
				// set a default if not set
				if ( scrollBy.length === 0 ) {
					scrollBy = 1;
				}
				
				$( '#sp-woocommerce-cart ul', mainContainer ).each( function() {
					var container = $( this ),
						runCarousel = true;

					// check if images are loaded first
					container.find( 'img.sp-woocommerce-dropshop-cart-item' ).eq( 0 ).load( this, function() {

						container.carouFredSel( {
							items: { 
								visible: visible,
							},
							circular: false,
							infinite: false,
							responsive: false,
							direction: orientation,
							align: 'center',
							//width: '100%', // 100% crashes browser when ajaxed and resized
							scroll: {
								items: scrollBy,
								duration: speed,
								easing: settings.easing
							},
							next: {
								button: $( '.sp-woocommerce-dropshop-next', mainContainer )
							},
							prev: {
								button: $( '.sp-woocommerce-dropshop-prev', mainContainer )
							},
							auto: {
								play: false
							},
							onCreate: function() { 
								// only work if in horizontal mode
								if ( settings.orientation === 'horizontal' ) {
									var currentVisibleItems,
										totalWidth = 0;

									// check how many items are currently visible 
									$( '#sp-woocommerce-cart ul', mainContainer ).trigger( 'currentVisible', function( items ) {
										currentVisibleItems = items.length; 
									} );
									// multiply total width of an item by currently visible items						
									totalWidth = currentVisibleItems * $( '.caroufredsel_wrapper li', mainContainer ).outerWidth( true );

									// set the carousel width dynamically
									$( '.caroufredsel_wrapper', mainContainer ).width( totalWidth );
									
									// set dropshop to be visible after create to prevent FOUC
									$( '#sp-woocommerce-cart', mainContainer ).css( 'visibility', 'visible');
								}
								// set the carousel to be inline-block so it can self-center
								$( '.caroufredsel_wrapper', mainContainer ).css( 'margin', '0' ).css( 'display', 'inline-block' );

								runCarousel = false;
							}
						});
					});

					if ( runCarousel ) {
						container.carouFredSel( {
							items: { 
								visible: visible,
							},
							circular: false,
							infinite: false,
							responsive: false,
							direction: orientation,
							align: 'center',
							//width: '100%', // 100% crashes browser when ajaxed and resized
							scroll: {
								items: scrollBy,
								duration: speed,
								easing: settings.easing
							},
							next: {
								button: $( '.sp-woocommerce-dropshop-next', mainContainer )
							},
							prev: {
								button: $( '.sp-woocommerce-dropshop-prev', mainContainer )
							},
							auto: {
								play: false
							},
							onCreate: function() { 
								// only work if in horizontal mode
								if ( settings.orientation === 'horizontal' ) {
									var currentVisibleItems,
										totalWidth = 0;

									// check how many items are currently visible 
									$( '#sp-woocommerce-cart ul', mainContainer ).trigger( 'currentVisible', function( items ) {
										currentVisibleItems = items.length; 
									} );
									// multiply total width of an item by currently visible items						
									totalWidth = currentVisibleItems * $( '.caroufredsel_wrapper li', mainContainer ).outerWidth( true );

									// set the carousel width dynamically
									$( '.caroufredsel_wrapper', mainContainer ).width( totalWidth );
									
									// set dropshop to be visible after create to prevent FOUC
									$( '#sp-woocommerce-cart', mainContainer ).css( 'visibility', 'visible');
								}
								// set the carousel to be inline-block so it can self-center
								$( '.caroufredsel_wrapper', mainContainer ).css( 'margin', '0' ).css( 'display', 'inline-block' );

								runCarousel = false;
							}
						});
					}
				});

				// get the center of the draggable image
				var itemImageTop = parseInt( $( '.products .product img.wp-post-image, .attachment-shop_catalog, .attachment-shop_single, .product img.wp-post-image' ).attr( 'height' ), 10 ) / 2,
					itemImageLeft = parseInt( $( '.products .product img.wp-post-image, .attachment-shop_catalog, .attachment-shop_single, .product img.wp-post-image' ).attr( 'width' ), 10 ) / 2;

				// set these two elements to be draggable from product page
				$( '.products .product img.wp-post-image, .attachment-shop_catalog, .attachment-shop_single, .product img.wp-post-image' ).draggable( {
					appendTo:   'body',
					helper:     'clone',
					opacity:    0.5,
					zIndex:     100001,
					cursor:     'move',
					cursorAt:   { top: itemImageTop, left: itemImageLeft }, // centers the cursor on the image when dragged
					start: function() {
						// clear popup container
						$( '.variation-popup-container' ).remove();

						// check if follow and vertical is set
						if ( settings.cart_follow === 'follow' && settings.orientation === 'vertical' ) {					
							// sets the position to absolute on start drag
							mainContainer.css( 'position', 'absolute' );	
						}
						
						// check orientation is set to horizontal
						if ( settings.orientation === 'horizontal' ) {
							// check if cart is not open and open it if so
							if ( mainContainer.css( 'bottom' ) !== '0' ) {
								mainContainer.animate( {bottom: '0'}, 500, 'swing' );
							}
						}
					},	

					drag: function( event, ui ) {
						$( '.sp-tooltip', mainContainer ).tooltip( 'destroy' );
						$( '.tooltip.fade.top.in' ).remove();

						// first check if cart follow is set
						if ( settings.cart_follow === 'follow' && settings.orientation === 'vertical' ) {
							clearFollow();
							
							// get the total height of container
							var cartHeight = mainContainer.outerHeight();
							
							// below is an arbitrary number to position the cart
							cartHeight = cartHeight / 2;

							// sets the top position to closely match the mouse location for easy drop
							mainContainer.css( 'top', ( ( ui.position.top + itemImageTop ) - cartHeight ) + 'px' );
						}

						if ( settings.orientation === 'horizontal' ) {
							// clear autohide when dragging
							clearAutoHide();
						}
					},

					stop: function() {
						setFollow();
						setAutoHide();

						// fades the items in the cart back to full opacity
						$( 'li.draggable-cart-item', mainContainer ).fadeTo( 400,'1' );

						$.woocommerce_dropshop_scripts.runTooltip();
					}
				});		
					
				// get the center of the draggable image
				var imageTop = $( '.draggable-cart-item img.sp-woocommerce-dropshop-cart-item', mainContainer ).height() / 2,
					imageLeft = $( '.draggable-cart-item img.sp-woocommerce-dropshop-cart-item', mainContainer ).width() / 2;

				// set the item inside the dropshop cart to be draggable
				$( '.draggable-cart-item', mainContainer ).draggable( {
					appendTo:	'body',
					opacity:	0.5,
					zIndex:		100001,
					cursor:		'move',
					cursorAt:	{ top: imageTop, left: imageLeft }, // centers the cursor on the image when dragged
					helper:		function() {
						return $( this ).find( 'img' ).clone();	
					},

					revert: 'invalid'
				});
				
				var droppableArea = $( '.sp-woocommerce-dropshop-inner', mainContainer );

				// check to see if cart is horizontal
				if ( settings.orientation === 'horizontal' ) {
					droppableArea = $( '.sp-woocommerce-dropshop-center', mainContainer );
				}

				function find_matching_variations( product_variations, settings ) {
					var matching = [];

					for ( var i = 0; i < product_variations.length; i++ ) {
						var variation = product_variations[i];

						if ( variations_match( variation.attributes, settings ) ) {
							matching.push( variation );
						}
					}
					return matching;
				}

				function variations_match( attrs1, attrs2 ) {
					var match = true,
						attr_name;

					for ( attr_name in attrs1 ) {
						if ( attrs1.hasOwnProperty( attr_name ) ) {
							var val1 = attrs1[ attr_name ],
								val2 = attrs2[ attr_name ];

							if ( val1 !== undefined && val2 !== undefined && val1.length !== 0 && val2.length !== 0 && val1 !== val2 ) {
								match = false;
							}
						}
					}

					return match;
				}

				function removePopup() {
					// remove the popup
					$( '.sp-woocommerce-dropshop-variation-popup-container' ).fadeOut( 'fast', function() {
						$( '.sp-woocommerce-dropshop-mask' ).fadeOut( 'fast' ).remove();
						$( '.sp-woocommerce-dropshop-variation-popup-container' ).remove();
					});

					setAutoHide();
					setFollow();
					return true;
				}

				function getPopup( response ) {
					// build the variation popup container
					var variationPopup = $( response.html ),
						mask = $( '<div class="sp-woocommerce-dropshop-mask"></div>' );

					// hide the mask
					mask.hide();

					// append mask to body
					$( 'body' ).append( mask );

					// remove the clear selection link
					variationPopup.find( '.reset_variations' ).remove();

					// hide the popup
					variationPopup.hide();

					// append popup to body
					$( 'body' ).append( variationPopup );

					// fade mask in
					mask.fadeIn( 'fast', function() {
						// fadein popup
						variationPopup.stop( true, true ).fadeIn( 600 );
					});

					// clear the timeout to wait for user input
					clearFollow();										

					$( variationPopup ).on( 'click', 'a.close-button', function( e ) {
						// prevent default behavior
						e.preventDefault();
						
						// remove the popup
						removePopup();
					});

					// bind click outsite of popup closes popup
					$( mask ).on( 'click', function() {
						// remove the popup
						removePopup();
					});
				}

				// set the drop spot in the cart and handle add to cart ajax
				droppableArea.droppable( {
					tolerance: 'pointer',
					accept: '.products .product img.wp-post-image, .product img.wp-post-image, .attachment-shop_catalog, .attachment-shop_single, .product img.wp-post-image',

					drop: function( event, ui ) {
						$( '.sp-tooltip', mainContainer ).tooltip( 'destroy' );
						$( '.tooltip.fade.top.in' ).remove();

						var productID = $( ui.draggable ).parents( '.product' ).find( '.button' ).attr( 'data-product_id' ),
							loadSpinner = $( '.sp-woocommerce-dropshop-dragdrop-spinner', mainContainer );

						// remove variation popup
						removePopup();

						$( 'p.sp-woocommerce-dropshop-cart-msg:visible', mainContainer ).hide();	
						loadSpinner.show(); 

						// if product id not found - probably no add to cart button search elsewhere						
						if ( typeof productID === 'undefined' ) {
							// try to grab it from list element
							productID = $( ui.draggable ).parents( '.product' ).attr( 'class' );

							var productClass = /post-\d+/.exec( productID );
							
							productID = /\d+/.exec( productClass );

							productID = productID[0];
						}

						var data = {
							'action':            'wc_dropshop_ajax_add_to_cart',
							'wc_dropshop_ajax':  woocommerce_dropshop.wc_dropshop_ajax_nonce,
							'product_id':        productID
						};

						$.post( woocommerce_dropshop.ajaxurl, data, function( response ) {
							response = $.parseJSON( response );

							switch( response.productType ) {
								case 'simple' :
									if ( response.added === true ) {
										$( 'body' ).trigger( 'added_to_cart' );

										if ( woocommerce_dropshop.is_single === 'false' ) {
											// add the added to cart class
											$( ui.draggable ).parents( '.product' ).find( '.button' ).addClass( 'added' );
										}

										setAutoHide();
									}
									break;									
								case 'variable' :
									getPopup( response );
									clearAutoHide();

									// get all available variations sets
									var all_variations = $( '.sp-woocommerce-dropshop-variation-popup-container form.variations_form' ).data( 'product_variations' );

									// when add to cart is clicked
									$( '.sp-woocommerce-dropshop-variation-popup-container' ).on( 'click', 'a.add-button', function( e ) {
										// prevent default behavior
										e.preventDefault();
										
										var allSelected = true;

										// loop through each select dropdown and make sure they are all set
										$( '.sp-woocommerce-dropshop-variation-popup-container' ).find( 'select' ).each( function() {
											// check condition
											if ( $( this ).val() === '' ) {
												allSelected = false;
												return;
											}
										});		

										// if all selected
										if ( allSelected ) {
											// remove the popup
											removePopup();

											loadSpinner.show();

											var current_settings = {};
											// grab each select value
											$( this ).parents( '.sp-woocommerce-dropshop-variation-popup-container' ).find( '.variations select' ).each( function() {
												// put each setting into array
												current_settings[ $( this ).attr( 'name' ) ] = $( this ).val();
											} );
											var matching_variations = find_matching_variations( all_variations, current_settings );
											
											var data = {
												'action':            'wc_dropshop_ajax_add_to_cart',
												'wc_dropshop_ajax':  woocommerce_dropshop.wc_dropshop_ajax_nonce,
												'product_id':        productID,
												'variation_id':      matching_variations[0].variation_id,
												'variations':        matching_variations[0].attributes
												};

											$.post( woocommerce_dropshop.ajaxurl, data, function( response ) {
												response = $.parseJSON( response );
												
												if ( response.added === true ) {
													$( 'body' ).trigger( 'added_to_cart' );

												} else if ( response.added === false ) {
													getPopup( response );
												}

												setFollow();
												setAutoHide();
											});												
										} else {
											if ( ! $( '.sp-woocommerce-dropshop-variation-popup-container p.not-selected-msg' ).length ) {
												$( '.sp-woocommerce-dropshop-variation-popup-container' ).append( $( '<p class="not-selected-msg">' + woocommerce_dropshop.select_all_options_msg + '</p>' ) );
											}
										}
									});
									break;
								case 'grouped' :
									getPopup( response );	
									setAutoHide();
									break;
								case 'external' :
									getPopup( response );
									setAutoHide();

									break;
							} // switch			
							loadSpinner.hide();

							$.woocommerce_dropshop_scripts.runTooltip();
						});				
						
						clearFollow();
					},	
					activeClass: 'ui-state-hover',
					hoverClass: 'ui-state-active',
					over: function() {
						// fade the cart items to give visual feedback when draggable items are on the drop zone.
						$( 'li.draggable-cart-item', mainContainer ).fadeTo( 400, '0.4' );	
					}
				});

				// this makes the items in the cart not droppable in itself
				mainContainer.droppable( {
					greedy: true,
					drop: function() {
						return false;
					}
				});
							
				// set the body area to be droppable for removing cart items and handle
				// ajax remove from cart
				$( 'body' ).droppable( {
					accept: $( '.draggable-cart-item', mainContainer ),
					drop: function( event, ui ) {
						$( '.sp-tooltip', mainContainer ).tooltip( 'destroy' );
						$( '.tooltip.fade.top.in' ).remove();

						var key = $( 'form input[name=cart_id]', ui.draggable ).val(),
							productID = $( 'form input[name=product_id]', ui.draggable ).val(),
							itemQuantity = $( 'form input[name=quantity]', ui.draggable ).val(),
							loadSpinner = $( '.sp-woocommerce-dropshop-dragdrop-spinner', mainContainer ),
							data = {
								'action':            'wc_dropshop_remove_item',
								'wc_dropshop_ajax':  woocommerce_dropshop.wc_dropshop_ajax_nonce,
								'cart_id':           key,
								'qty':               itemQuantity
							};
						
						loadSpinner.show();
						
						$.post( woocommerce_dropshop.ajaxurl, data, function( response ) {
							if ( response ) {
								$( 'body' ).trigger( 'remove_item' );

								// remove any added class to products
								$( '.products .product a.add_to_cart_button[data-product_id=' + productID + ']' ).removeClass( 'added' );

								// for wootique remove view cart html as well
								$( '.products .product a.add_to_cart_button[data-product_id=' + productID + ']' ).next( 'a.added_to_cart' ).remove();
								
								setAutoHide();
							}
							
							loadSpinner.hide();
							$.woocommerce_dropshop_scripts.runTooltip();
						});
					}
				});
				
				// handle ajax remove item from cart when remove button is clicked
				$( '.draggable-cart-item a.sp-woocommerce-dropshop-item-remover', mainContainer ).click( function() {
					$( '.sp-tooltip', mainContainer ).tooltip( 'destroy' );

					var productID = $( this ).parent().attr( 'id' ),
						key = $( '#' + productID +  ' form input[name=cart_id]' ).val(),
						itemQuantity = $( '#' + productID + ' form input[name=quantity]' ).val(),
						loadSpinner = $( '.sp-woocommerce-dropshop-dragdrop-spinner', mainContainer ),
						data = {
							'action':            'wc_dropshop_remove_item',
							'wc_dropshop_ajax':  woocommerce_dropshop.wc_dropshop_ajax_nonce,
							'cart_id':           key,
							'qty':               itemQuantity
						};					
					
					loadSpinner.show();
					$.post( woocommerce_dropshop.ajaxurl, data, function( response ) {
						if ( response ) {
							$( 'body' ).trigger( 'remove_item' );

							// remove any added class to products
							$( '.products .product a.add_to_cart_button[data-product_id=' + productID.replace( /\D/g, '' ) + ']' ).removeClass( 'added' );	

							// for wootique remove view cart html as well
							$( '.products .product a.add_to_cart_button[data-product_id=' + productID.replace( /\D/g, '' ) + ']' ).next( 'a.added_to_cart' ).remove();

							setAutoHide();
						}

						loadSpinner.hide();
						$.woocommerce_dropshop_scripts.runTooltip();
					});
					
					return false;
				});	
				
				// if mouse is hovered over the cart, don't hide or stop follow
				mainContainer.mouseover( function( e ) {
					e.stopPropagation();

					clearAutoHide();
					clearFollow();
				}).mouseout( function( e ) {
					e.stopPropagation();

					setAutoHide();
					setFollow();
				});	
				
			}, // close init		
			
			runTooltip: function() {
				// check for tooltip
				if ( settings.show_product_title === 'on' ) {
					$( '.sp-tooltip', mainContainer ).tooltip( { container: 'body', placement: 'top' } );
				}
			},

			refreshCart: function() {
				// remove all tooltip
				$( '.sp-tooltip', mainContainer ).tooltip( 'destroy' );
				$( '.tooltip.fade.top.in' ).remove();

				// bind the add to cart refresh from WooCommerce
				$( 'body' ).on( 'added_to_cart remove_item', function( e ) {
					var data = {
						'action':            'wc_dropshop_refresh',
						'wc_dropshop_ajax':  woocommerce_dropshop.wc_dropshop_ajax_nonce,
						'settings':          $.parseJSON( $( '.sp-woocommerce-dropshop-settings', mainContainer ).val() )
					};				

					$.post( woocommerce_dropshop.ajaxurl, data, function( response ) {
							response = $.parseJSON( response );
						
						var title = $( '.widget-title', mainContainer );

						// this check is necessary incase theme has own widget title insertion
						if ( title.length < 1 ) { 
							title = $( 'h3:first-child', mainContainer );
						}

						mainContainer.html( response.dropshop );
						
						// replace the title
						mainContainer.prepend( title );

						$.woocommerce_dropshop_scripts.init(); // reinitialize scripts

						var widgetTitle = $( '.widget_shopping_cart .widget-title' );
						
						// this check is necessary incase theme has own widget title insertion
						if ( widgetTitle.length < 1 ) { 
							widgetTitle = $( '.widget_shopping_cart h3:first-child' );
						}
						
						// refresh the default woocommerce cart
						$( '.widget_shopping_cart' ).html( response.woocart );

						// replace the title
						$( '.widget_shopping_cart' ).prepend( title );

						// if there are header cart info to update
						if ( response.wooheadercart.length ) {
							// artificer, wootique
							$( 'a.cart-button' ).replaceWith( response.wooheadercart );
							// mystile
							$( 'a.cart-parent' ).replaceWith( response.wooheadercart );
						}

						$.woocommerce_dropshop_scripts.runTooltip();
					});

					// user callback for adding items
					if ( e.type === 'added_to_cart' ) {
						$( 'body' ).trigger( 'adding_item' );

						if ( settings.orientation === 'horizontal' ) {
							// slide up the cart to show added content
							mainContainer.stop().animate( {bottom: '0'}, 500, 'swing' );
						}
					}

					// user callback for removing items
					if ( e.type === 'remove_item' ) {
						if ( settings.autohide === 'on' ) {
							$( 'body' ).trigger( 'removing_item' );
						}
					}
				});
			} // close refreshCart
		}; // close namespace
	
		$.woocommerce_dropshop_scripts.refreshCart();
		$.woocommerce_dropshop_scripts.init();
		$.woocommerce_dropshop_scripts.runTooltip();
	});	
});