<?php
/**
 * extended widget class
 * @package WC_Dropshop
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // no direct access
}

class WC_Dropshop_Frontend_Ajax {
	/**
	 * init
	 *
	 * @access public
	 * @since 2.0.0
	 * @return bool
	 */
	public function __construct() {
		if ( is_admin() ) {
			add_action( 'wp_ajax_nopriv_wc_dropshop_refresh', array( $this, 'refresh' ) );
			add_action( 'wp_ajax_wc_dropshop_refresh', array( $this, 'refresh' ) );
			add_action( 'wp_ajax_nopriv_wc_dropshop_remove_item', array( $this, 'remove_item' ) );
			add_action( 'wp_ajax_wc_dropshop_remove_item', array( $this, 'remove_item' ) );
			add_action( 'wp_ajax_nopriv_wc_dropshop_ajax_add_to_cart', array( $this, 'ajax_add_to_cart' ) );
			add_action( 'wp_ajax_wc_dropshop_ajax_add_to_cart', array( $this, 'ajax_add_to_cart' ) );	
		}

		return true;
	}

	/**
	 * this function handles the cart display on ajax refresh
	 *
	 * @access public
	 * @since 2.0.0
	 * @return string $output the HTML of the cart
	 */
	public function refresh() {
		global $sp_woocommerce_dropshop_settings;

		$nonce = $_POST['wc_dropshop_ajax'];
		// bail if nonce don't match
		if ( ! wp_verify_nonce( $nonce, 'wc_dropshop_ajax_nonce' ) ) 
		     wp_die( 'No Way' );

		$sp_woocommerce_dropshop_settings = $_POST['settings'];

		// get the dropshop template
		ob_start();
		require_once( WC_DROPSHOP_PATH . 'templates/wc-dropshop-widget-display-html.php' );
		$dropshop_output = ob_get_clean();

		// get the woocommerce mini cart template
		ob_start();
		woocommerce_get_template( 'cart/mini-cart.php', array( 'list_class' => '' ) );
		$woocart_output = ob_get_clean();

		if ( function_exists( 'woocommerce_cart_link' ) ) {
			// get the cart link info
			ob_start();
			woocommerce_cart_link();
			$woo_header_cart_output = ob_get_clean();
		} else {
			$woo_header_cart_output = '';
		}

		$output = array( 'dropshop' => $dropshop_output, 'woocart' => $woocart_output, 'wooheadercart' => $woo_header_cart_output );
		echo json_encode( $output );
		exit;
	}

	/**
	 * this function handles the remove item function
	 *
	 * @access public
	 * @since 2.0.0
	 * @return boolean true
	 */
	public function remove_item() {
		$nonce = $_POST['wc_dropshop_ajax'];
		// bail if nonce don't match
		if ( ! wp_verify_nonce( $nonce, 'wc_dropshop_ajax_nonce' ) ) 
		     wp_die( 'No Way' );

		$cart_id = $_POST['cart_id'];
		$qty = absint( $_POST['qty'] );

		// decrement qty by 1
		$qty = $qty - 1;

		// make sure qty is not negative
		if ( $qty < 0 ) { 
		  $qty = 0;        
		}	

		// sets the new quantity
		WC()->cart->set_quantity( $cart_id, $qty );

		echo true;
		exit; 
	}	

	/**
	 * Function that handles the ajax add to cart when no add to cart button is found
	 *
	 * @access public
	 * @since 2.0.0
	 * @return boolean true
	 */
	public function ajax_add_to_cart() {
		global $product, $post;

		$nonce = $_POST['wc_dropshop_ajax'];

		// bail if nonce don't match
		if ( ! wp_verify_nonce( $nonce, 'wc_dropshop_ajax_nonce' ) ) 
		     wp_die( 'No Way' );

		$product_id			= apply_filters( 'woocommerce_add_to_cart_product_id', $_POST['product_id'] );
		$quantity			= empty( $_POST['quantity'] ) ? 1 : apply_filters( 'woocommerce_stock_amount', $_POST['quantity'] );
		$variation_id		= empty( $_POST['variation_id'] ) ? '' : absint( $_POST['variation_id'] );
		$variations 		= empty( $_POST['variations'] ) ? '' : $_POST['variations'];

		// get the product type
		$product = get_product( $product_id );

		// set post global
		$post = get_post( $product_id );

		switch( $product->product_type ) {
			case 'simple' :
				// Add to cart validation
				$passed_validation 	= apply_filters( 'woocommerce_add_to_cart_validation', true, $product_id, $quantity );

				if ( $passed_validation ) {		
					// if add to cart successfully
					if ( WC()->cart->add_to_cart( $product_id, $quantity ) ) {		    						
						$output = json_encode( array( 'added' => true, 'productType' => 'simple' ) );
					} else {
						$output = json_encode( array( 'added' => false, 'productType' => 'simple' ) );
					}
				}
				break;
			case 'variable' :
				// check if variation is set
				if ( empty( $variation_id ) ) {
					// get the variation select dropdown html
					
					ob_start();
					woocommerce_get_template( 'single-product/add-to-cart/variable.php', array(
						'available_variations' => $product->get_available_variations(),
						'attributes'           => $product->get_variation_attributes(),
						'selected_attributes'  => $product->get_variation_default_attributes()
					) );

					$woo_variations = ob_get_clean();

	        		$html = '';
	        		$html .= '<div class="sp-woocommerce-dropshop-variation-popup-container">' . "\r\n";
	        		$html .= '<p class="sp-woocommerce-dropshop-cart-msg">' . "\r\n";
	        		$html .= apply_filters( 'sp_woocommerce_dropshop_options_not_set_text', __( 'This product has options. Please select the options below.', 'woocommerce-dropshop' ) ) . "\r\n";
	        		$html .= '</p>' . "\r\n";
	        		$html .= $woo_variations . "\r\n";
	        		$html .= '<a href="#" class="add-button">' . apply_filters( 'sp_woocommerce_dropshop_add_to_cart_button_text', __( 'Add to Cart', 'woocommerce-dropshop' ) ) . '</a>' . "\r\n";
	        		$html .= '<a href="' . get_permalink( $product_id ) . '" class="detail-link">' . apply_filters( 'sp_woocommerce_dropshop_detail_button_text', __( 'More Detail', 'woocommerce-dropshop' ) ) . '</a>' . "\r\n";
	        		$html .= '<a href="#" title="' . esc_attr__( 'Close', 'woocommerce-dropshop' ) . '" class="close-button"><i class="icon"></i></a>' . "\r\n";
	        		$html .= '</div>' . "\r\n";

					$output = json_encode( array( 'added' => false, 'productType' => 'variable', 'html' => $html ) );
				} else {
		        	// Add to cart validation
		        	$passed_validation = apply_filters( 'woocommerce_add_to_cart_validation', true, $product_id, $quantity, $variation_id, $variations );

		        	if ( $passed_validation ) {
		        		// if added successfully
						if ( WC()->cart->add_to_cart( $product_id, $quantity, $variation_id, $variations ) ) { 
							$output = json_encode( array( 'added' => true, 'productType' => 'variable' ) );
						} else {
			        		$html = '';
			        		$html .= '<div class="sp-woocommerce-dropshop-variation-popup-container">' . "\r\n";
			        		$html .= '<p class="sp-woocommerce-dropshop-cart-msg">' . "\r\n";
			        		$html .= apply_filters( 'sp_woocommerce_dropshop_error', __( 'Sorry, there was an issue with adding this product to the cart.  Please click the more detail link button and try there.', 'woocommerce-dropshop' ) ) . "\r\n";
			        		$html .= '</p>' . "\r\n";
			        		$html .= '<a href="' . get_permalink( $product_id ) . '" class="detail-link">' . apply_filters( 'sp_woocommerce_dropshop_detail_button_text', __( 'More Detail', 'woocommerce-dropshop' ) ) . '</a>' . "\r\n";
			        		$html .= '<a href="#" title="' . esc_attr__( 'Close', 'woocommerce-dropshop' ) . '" class="close-button"><i class="icon"></i></a>' . "\r\n";
			        		$html .= '</div>' . "\r\n";			
			        					
							$output = json_encode( array( 'added' => false, 'productType' => 'variable', 'html' => $html ) );
						}
					}
				}
				break;

			case 'grouped' :
	    		$html = '';
	    		$html .= '<div class="sp-woocommerce-dropshop-variation-popup-container">' . "\r\n";
	    		$html .= '<p class="sp-woocommerce-dropshop-cart-msg">' . "\r\n";
	    		$html .= apply_filters( 'sp_woocommerce_dropshop_grouped_product_msg', __( 'This is a grouped product.  Please go to the product detail page to add this item to the cart.', 'woocommerce-dropshop' ) ) . "\r\n";
	    		$html .= '</p>' . "\r\n";
	    		$html .= '<a href="' . get_permalink( $product_id ) . '" class="detail-link">' . apply_filters( 'sp_woocommerce_dropshop_detail_button_text', __( 'More Detail', 'woocommerce-dropshop' ) ) . '</a>' . "\r\n";
	    		$html .= '<a href="#" title="' . esc_attr__( 'Close', 'woocommerce-dropshop' ) . '" class="close-button"><i class="icon"></i></a>' . "\r\n";
	    		$html .= '</div>' . "\r\n";	

				$output = json_encode( array( 'added' => false, 'productType' => 'grouped', 'html' => $html ) );
				break;

			case 'external' :
				// get products external url
				$external_url = get_post_meta( $product_id, '_product_url', true );

	    		$html = '';
	    		$html .= '<div class="sp-woocommerce-dropshop-variation-popup-container">' . "\r\n";
	    		$html .= '<p class="sp-woocommerce-dropshop-cart-msg">' . "\r\n";
	    		$html .= apply_filters( 'sp_woocommerce_dropshop_external_product_msg', __( 'This is an external product.  Please click on the detail link to go to the product\'s page.', 'woocommerce-dropshop' ) ) . "\r\n";
	    		$html .= '</p>' . "\r\n";
	    		$html .= '<a href="' . esc_url( $external_url ) . '" class="detail-link">' . apply_filters( 'sp_woocommerce_dropshop_detail_button_text', __( 'More Detail', 'woocommerce-dropshop' ) ) . '</a>' . "\r\n";
	    		$html .= '<a href="#" title="' . esc_attr__( 'Close', 'woocommerce-dropshop' ) . '" class="close-button"><i class="icon"></i></a>' . "\r\n";
	    		$html .= '</div>' . "\r\n";	

				$output = json_encode( array( 'added' => false, 'productType' => 'grouped', 'html' => $html ) );
				break;
		}

		echo $output;
		exit;
	}	
}

new WC_Dropshop_Frontend_Ajax();