<?php
/**
 * extended widget class
 * @package WC_Dropshop
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // no direct access
}

class WC_Dropshop_Frontend {
	/**
	 * init
	 *
	 * @access public
	 * @since 2.0.0
	 * @return bool
	 */
	function __construct() {
		// don't load scripts in the backend
		if ( ! is_admin() ) {
			// add action to the wp_enqueue_scripts hook
			add_action( 'wp_enqueue_scripts', array( $this, 'wc_dropshop_frontend_scripts' ) );

			add_action( 'wp_enqueue_scripts', array( $this, 'wc_dropshop_frontend_styles' ), 99 );
		}		

		return true;
	}

	/**
	 * this function loads the necessary frontend scripts
	 *
	 * @access private
	 * @since 1.0
	 * @return boolean true
	 */
	public function wc_dropshop_frontend_scripts() {

		$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		wp_enqueue_script( 'jquery' );
		
		// due to a bug in jQuery UI in the later versions which causes draggable items cursor to mis align if
		// browser window is scrolled down, we must enqueue older versions of the jQuery UI. See http://bugs.jqueryui.com/ticket/9315
		// you may filter this out if not needed.

		if ( apply_filters( 'sp_woocommerce_dropshop_use_legacy_jquery_ui', true ) ) {
			// remove any jQuery UI scripts
			wp_dequeue_script( 'jquery-ui-core' );
			wp_deregister_script( 'jquery-ui-core' );

			wp_dequeue_script( 'jquery-ui-mouse' );
			wp_deregister_script( 'jquery-ui-mouse' );

			wp_dequeue_script( 'jquery-ui-draggable' );
			wp_deregister_script( 'jquery-ui-draggable' );

			wp_dequeue_script( 'jquery-ui-widget' );
			wp_deregister_script( 'jquery-ui-widget' );

			wp_dequeue_script( 'jquery-ui-droppable' );
			wp_deregister_script( 'jquery-ui-droppable' );

			// enqueue legacy versions of jQuery UI
			wp_register_script( apply_filters( 'sp_woocommerce_dropshop_jquery_ui_core', 'jquery-ui-core' ), WC_DROPSHOP_URL . 'assets/js/jquery-fix/jquery.ui.core.min.js' );
			wp_enqueue_script( apply_filters( 'sp_woocommerce_dropshop_jquery_ui_core', 'jquery-ui-core' ) );

			wp_register_script( apply_filters( 'sp_woocommerce_dropshop_jquery_ui_widget', 'jquery-ui-widget' ), WC_DROPSHOP_URL . 'assets/js/jquery-fix/jquery.ui.widget.min.js' );
			wp_enqueue_script( apply_filters( 'sp_woocommerce_dropshop_jquery_ui_widget', 'jquery-ui-widget' ) );

			wp_register_script( apply_filters( 'sp_woocommerce_dropshop_jquery_ui_mouse', 'jquery-ui-mouse' ), WC_DROPSHOP_URL . 'assets/js/jquery-fix/jquery.ui.mouse.min.js' );
			wp_enqueue_script( apply_filters( 'sp_woocommerce_dropshop_jquery_ui_mouse', 'jquery-ui-mouse' ) );

			wp_register_script( apply_filters( 'sp_woocommerce_dropshop_jquery_ui_draggable', 'jquery-ui-draggable' ), WC_DROPSHOP_URL . 'assets/js/jquery-fix/jquery.ui.draggable.min.js' );
			wp_enqueue_script( apply_filters( 'sp_woocommerce_dropshop_jquery_ui_draggable', 'jquery-ui-draggable' ) );

			wp_register_script( apply_filters( 'sp_woocommerce_dropshop_jquery_ui_droppable', 'jquery-ui-droppable' ), WC_DROPSHOP_URL . 'assets/js/jquery-fix/jquery.ui.droppable.min.js' );
			wp_enqueue_script( apply_filters( 'sp_woocommerce_dropshop_jquery_ui_droppable', 'jquery-ui-droppable' ) );
		} else {
			wp_enqueue_script( 'jquery-ui-core' );

			wp_enqueue_script( 'jquery-ui-draggable' );

			wp_enqueue_script( 'jquery-ui-droppable' );
		}

		wp_register_script( apply_filters( 'sp_woocommerce_dropshop_caroufredsel', 'caroufredsel' ), WC_DROPSHOP_URL .  'assets/js/jquery.carouFredSel.packed.js', array( 'jquery' ), '6.2.1', true );
		wp_enqueue_script( apply_filters( 'sp_woocommerce_dropshop_caroufredsel', 'caroufredsel' ) );

		wp_register_script( apply_filters( 'sp_woocommerce_dropshop_bootstrap', 'bootstrap' ), WC_DROPSHOP_URL .  'assets/js/bootstrap.min.js', array( 'jquery' ), '3.1.1', true );
		wp_enqueue_script( apply_filters( 'sp_woocommerce_dropshop_bootstrap', 'bootstrap' ) );

		wp_register_script( 'sp-woocommerce-dropshop-script', WC_DROPSHOP_URL . 'assets/js/dropshop' . $suffix . '.js', array( 'jquery' ), WC_DROPSHOP_VERSION, true );  

		wp_enqueue_script( 'sp-woocommerce-dropshop-script' );
		
		// set the localized variables
		$localized_vars = array(
			'ajaxurl'                => admin_url( 'admin-ajax.php' ),
			'wc_dropshop_ajax_nonce' => wp_create_nonce( 'wc_dropshop_ajax_nonce' ),
			'select_all_options_msg' => apply_filters( 'sp_woocommerce_dropshop_select_all_options_msg', __( 'Please select all options before clicking on add to cart.', 'woocommerce-dropshop' ) ),
			'is_single'              => is_product() ? 'true' : 'false'
		);
		
		wp_localize_script( 'sp-woocommerce-dropshop-script', 'woocommerce_dropshop', $localized_vars );	
		
		return true;
	}


	/**
	 * this function loads the necessary frontend styles
	 *
	 * @access private
	 * @since 1.0
	 * @return boolean true
	 */	
	public function wc_dropshop_frontend_styles() {
		wp_register_style( 'sp-woocommerce-dropshop-styles', WC_DROPSHOP_URL . 'assets/css/dropshop.css', '', WC_DROPSHOP_VERSION );
		wp_enqueue_style( 'sp-woocommerce-dropshop-styles' );	
		
		return true;
	}

	/**
	 * Gets the image if one is set to display in the cart
	 *
	 * @access public
	 * @since 1.0
	 * @param int $product_id Pass in a product id
	 * @param int $variation_id Pass in a variation id
	 * @param int $image_width Pass in the width of the cart image
	 * @param int $image_height Pass in the height of the cart image
	 * @return string $image The URL of the image
	 */
	public function get_cart_item_image( $product_id = 1, $variation_id = 1, $image_width = 50, $image_height = 50 ) {
		
		if ( isset( $variation_id ) && ! empty( $variation_id ) ) {

			// get the variation image
			$attach_id = get_post_meta( $variation_id, '_thumbnail_id', true );
			
			// get the image source
			$image = wp_get_attachment_image_src( $attach_id, array( $image_width, $image_height ) );

			// if image is found
			if ( $image ) {
			  $image = $image[0];  
			} else {
				// get the product image
				$attach_id = get_post_meta( $product_id, '_thumbnail_id', true );
				
				// get the image source
				$image = wp_get_attachment_image_src( $attach_id, array( $image_width, $image_height ) );			

				if ( $image ) {
					$image = $image[0];
				} else {
			  		return wc_placeholder_img_src();  
			  	}
			}
		} else {
			// get the product image
			$attach_id = get_post_meta( $product_id, '_thumbnail_id', true );
			
			// get the image source
			$image = wp_get_attachment_image_src( $attach_id, array( $image_width, $image_height ) );			

			if ( $image ) {
				$image = $image[0];
			} else {
		  		return wc_placeholder_img_src();  
		  	}
		}	
		
		return $image;
	}
}

