<?php
/**
 * extended widget class
 * @package WC_Dropshop
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // no direct access
}

/**
 * class that extends WordPress Widget
 *
 * @since 1.0
 */ 
class WC_Dropshop_Widget extends WP_Widget {
	/**
	 * constructor.
	 *
	 * @access public
	 * @since 1.0
	 * @return boolean true.
	 */
	public function WC_Dropshop_Widget() {
		global $pagenow;

		parent::__construct( false, __( 'WooCommerce Drag N Drop Shop', 'woocommerce-dropshop' ) );

		// widget settings
		$widget_ops = array( 'classname' => 'sp-woocommerce-drop-shop', 'description' => __( 'Add a drag and drop widget to your sidebars for easier and faster purchases.', 'woocommerce-dropshop' ) );

		// widget control settings
		$control_ops = array( 'id_base' => 'sp-woocommerce-drop-shop-widget', 'width' => 582 );

		// create widget
		$this->WP_Widget( 'sp-woocommerce-drop-shop-widget', __( 'WooCommerce Drag N Drop Shop', 'woocommerce-dropshop' ), $widget_ops, $control_ops );

		if ( is_admin() && $pagenow === 'widgets.php' ) {
			// add action to the wp_enqueue_scripts hook
			add_action( 'admin_enqueue_scripts', array( $this, 'wc_dropshop_backend_scripts' ) );
		}	

		return true;	
	}	
	
	/**
	 * frontend widget display.
	 *
	 * @access public
	 * @since 1.0
	 * @param array $args Widget arguments.
	 * @param array $instance Saved values from database. 
	 * @return $output string HTML.
	 */
	public function widget( $args, $instance ) {
		global $sp_woocommerce_dropshop_settings;

		do_action( 'sp_woocommerce_dropshop_before_output' );
		
		// get exlude pages
		$exclude_pages = $instance['exclude_pages'];
		
		if ( isset( $exclude_pages ) && ! empty( $exclude_pages ) )
			$exclude_pages = array_map( 'intval', explode( ',', trim( $exclude_pages ) ) );

		// get exlude categories
		$exclude_categories = $instance['exclude_categories'];

		if ( isset( $exclude_categories ) && ! empty( $exclude_categories ) )
			$exclude_categories = explode( ',', trim( strtolower( $exclude_categories ) ) );

		if ( ! empty( $exclude_pages ) && is_page( $exclude_pages ) )
			return;

		if ( ! empty( $exclude_categories ) && is_product_category( $exclude_categories ) )
			return;

		// show on show pages only
		$show_on_shop = $instance['show_on_shop'];

		if ( isset( $show_on_shop ) && $show_on_shop === 'on' ) {
			if ( get_post_type() !== 'product' )
				return;
		}

		// show on single
		$show_on_single = $instance['show_on_single'];
		
		// don't continue if show on single is off.
		if ( is_product() && isset( $show_on_single ) && $show_on_single !== 'on' )
			return;

		extract( $args );

		// user set title
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		$output = '';
		
		// before widget
		$output .= $before_widget;
		
		// get cart bg color
		$cart_bg_color = $instance['cart_bg_color'];
		
		// get text color
		$text_color = $instance['text_color'];
		
		$style = '';		

		// check if custom is turned on
		if ( $instance['custom'] === 'on' ) {
			
			// check if background color is set
			if ( isset( $cart_bg_color ) && $cart_bg_color != '' )
				$style .= 'background-image:none;background-color:' . $cart_bg_color . ';';	
			
			// check if text color is set
			if ( isset( $text_color ) && $text_color != '' )
				$style .= ' color:' . $text_color . ';';
				
		}

		if ( isset( $instance['autohide_default'] ) && $instance['autohide_default'] === 'hide' ) {
			$style .= 'bottom:-105px;';
		}	
				
		// outer container
		$output .= '<div class="sp-woocommerce-dropshop-container group ' . esc_attr( $instance['orientation'] ) . ' arrow-' . esc_attr( $instance['arrow_color'] ) . ' font-' . esc_attr( $instance['font_style'] ) . ' ' . esc_attr( $instance['theme'] ) . '-theme custom-' . esc_attr( $instance['custom'] ) . '" style="' . esc_attr( $style ) . '">';

		// title of the widget
		if ( $title )
			$output .= $before_title . $title . $after_title;

		// build settings array
		$settings = array(
			'orientation'        => $instance['orientation'],
			'cart_follow'        => $instance['cart_follow'],
			'visible'            => $instance['visible'],
			'speed'              => $instance['speed'],
			'autohide'           => $instance['autohide'],
			'autohide_duration'  => $instance['autohide_duration'],
			'autohide_default'   => $instance['autohide_default'],
			'scrollby'           => $instance['scrollby'],
			'custom'             => $instance['custom'],
			'btn_bg_color'       => $instance['btn_bg_color'],
			'btn_bg_color_hv'    => $instance['btn_bg_color_hv'],
			'cart_bg_color'      => $instance['cart_bg_color'],
			'inset_bg_color'     => $instance['inset_bg_color'],
			'inset_shadow'       => $instance['inset_shadow'],
			'inset_corners'      => $instance['inset_corners'],
			'text_color'         => $instance['text_color'],
			'easing'             => $instance['easing'],
			'btn_text_color'     => $instance['btn_text_color'],
			'show_product_title' => $instance['show_product_title'],
			'show_item_count'    => $instance['show_item_count'],
			'theme'              => $instance['theme']
		);

		// assign to global variable
		$sp_woocommerce_dropshop_settings = $settings;

		// gets the display template
		ob_start();
		include_once( apply_filters( 'sp_woocommerce_dropshop_widget_template_path', WC_DROPSHOP_PATH . 'templates/wc-dropshop-widget-display-html.php' ) );
		$output .= ob_get_clean();

		$settings = json_encode( $settings );

		// close outer container
		$output .= '</div><!--close sp-woocommerce-dropshop-->';

		// after widget
		$output .= $after_widget;
		
		echo $output;
	}	

	/**
	 * updates widget in backend.
	 *
	 * @access public
	 * @since 1.0
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 * @return array $instance Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		
		$instance['title']              = esc_attr( strip_tags( $new_instance['title'] ) );
		$instance['visible']            = sanitize_text_field( $new_instance['visible'] );
		$instance['orientation']        = sanitize_text_field( $new_instance['orientation'] );
		$instance['autohide']           = isset( $new_instance['autohide'] ) ? 'on' : 'off';
		$instance['autohide_duration']  = sanitize_text_field( $new_instance['autohide_duration'] );
		$instance['autohide_default']   = sanitize_text_field( $new_instance['autohide_default'] );
		$instance['theme']              = sanitize_text_field( $new_instance['theme'] );
		$instance['speed']              = absint( $new_instance['speed'] );
		$instance['scrollby']           = sanitize_text_field( $new_instance['scrollby'] );
		$instance['custom']             = isset( $new_instance['custom'] ) ? 'on' : 'off';
		$instance['cart_bg_color']      = sanitize_text_field( $new_instance['cart_bg_color'] );
		$instance['font_style']         = sanitize_text_field( $new_instance['font_style'] );
		$instance['text_color']         = sanitize_text_field( $new_instance['text_color'] );
		$instance['btn_text_color']     = sanitize_text_field( $new_instance['btn_text_color'] );
		$instance['btn_bg_color']       = sanitize_text_field( $new_instance['btn_bg_color'] );
		$instance['btn_bg_color_hv']    = sanitize_text_field( $new_instance['btn_bg_color_hv'] );		
		$instance['arrow_color']        = sanitize_text_field( $new_instance['arrow_color'] );
		$instance['cart_follow']        = sanitize_text_field( $new_instance['cart_follow'] );
		$instance['easing']             = sanitize_text_field( $new_instance['easing'] );
		$instance['inset_bg_color']     = sanitize_text_field( $new_instance['inset_bg_color'] );
		$instance['inset_corners']      = sanitize_text_field( $new_instance['inset_corners'] );
		$instance['inset_shadow']       = sanitize_text_field( $new_instance['inset_shadow'] );
		$instance['show_on_single']     = isset( $new_instance['show_on_single'] ) ? 'on' : 'off';
		$instance['show_on_shop']       = isset( $new_instance['show_on_shop'] ) ? 'on' : 'off';
		$instance['exclude_pages']      = sanitize_text_field( $new_instance['exclude_pages'] );
		$instance['exclude_categories'] = sanitize_text_field( $new_instance['exclude_categories'] );
		$instance['show_item_count']    = isset( $new_instance['show_item_count'] ) ? 'on' : 'off';
		$instance['show_product_title'] = isset( $new_instance['show_product_title'] ) ? 'on' : 'off';
		
		return $instance;
	}
	
	/**
	 * backend widget ui.
	 *
	 * @access public
	 * @since 1.0
	 * @param array $instance Previously saved values from database.
	 * @return boolean true.
	 */
	public function form( $instance ) {
		$defaults = array( 
			'title'              => sprintf( '%s', __( 'Shopping Cart', 'woocommerce-dropshop' ) ),
			'visible'            => 3, // items to display
			'scrollby'           => 1, // set the number of items to scroll by on click
			'speed'              => 800, // sets the speed of the scroll itself
			'orientation'        => 'vertical', // sets the orientation of the drop layout vertical/horizontal
			'autohide'           => 'on', // sets the autohide function on horizontal layout
			'autohide_duration'  => 10, // sets how long before horizonal cart hides itself
			'autohide_default'   => 'show', // sets the default position of the horizonal cart hidden or shown
			'theme'              => 'light', // sets the theme to light/dark
			'custom'             => 'off', // sets if custom styles are being used
			'cart_bg_color'      => '#eee', // sets the cart background color
			'font_style'         => 'sans-serif', // sets the style of the text/font
			'text_color'         => '#333', // sets the default text color
			'btn_text_color'     => '#fff', // sets the default button text color
			'btn_bg_color'       => '#333', // set the checkout and view cart button color
			'btn_bg_color_hv'    => '#333', // set the checkout and view cart button color on hover
			'arrow_color'        => 'light', // sets the arrow color
			'cart_follow'        => 'no-follow', // sets the cart to follow mouse
			'easing'             => 'elastic', // sets the easing effect on scroll
			'inset_bg_color'     => '#999', // sets the background color of the inset section
			'inset_corners'      => 'true', // sets the corners of the inset
			'inset_shadow'       => 'true', // sets the inset inner shadows
			'show_on_single'     => 'false', // sets the display of cart on single product page
			'show_on_shop'       => 'false', // sets the display of cart on shop pages only
			'show_item_count'    => 'true', // sets the display of item count
			'show_product_title' => 'true', // sets the display of product title on hover
			'exclude_pages'      => '', // comma separated list of page ids to not show on
			'exclude_categories' => '' // comma separated list of category ids to not show on
		);
					
		$instance = wp_parse_args( ( array ) $instance, $defaults ); 
		
		?>
		<?php
		$ajax_add_to_cart = get_option( 'woocommerce_enable_ajax_add_to_cart' );
		$redirect_to_cart = get_option( 'woocommerce_cart_redirect_after_add' );

		if ( $ajax_add_to_cart === 'no' || $redirect_to_cart === 'yes' ) { ?>
			<p class="sp-woocommerce-dropshop-warning"><?php _e( 'Please make sure "ajax add to cart" is enabled and "redirect to cart" is disabled.  This warning will go away once this is done.', 'woocommerce-dropshop' ); ?></p>
		<?php 
		}
		?>
		<div class="sp-woocommerce-dropshop-col1">
			<p>
				<?php _e( 'Please note only ONE instance of this widget should be used at any time', 'woocommerce-dropshop' ); ?>
			</p>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title:', 'woocommerce-dropshop' ); ?></label>
				<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" />
			</p>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'orientation' ) ); ?>"><?php _e( 'DropShop Orientation:', 'woocommerce-dropshop' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'orientation' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'orientation' ) ); ?>" class="sp-woocommerce-dropshop-orientation-select widefat">
					<option value="vertical" <?php selected( $instance['orientation'], 'vertical' ); ?>><?php _e( 'Vertical', 'woocommerce-dropshop' ); ?></option>
					<option value="horizontal" <?php selected( $instance['orientation'], 'horizontal' ); ?>><?php _e( 'Horizontal', 'woocommerce-dropshop' ); ?></option>
				</select><br />
				<small><?php _e( 'For DropShop to appear wider (most footers), choose horizontal.  For DropShop to appear taller (most sidebars), choose vertical.', 'woocommerce-dropshop' ); ?></small>
			</p>
			<?php
			// check orientation selected state
			$follow_area = 'display:block;';
			$autohide_area = 'display:block;';	
			if ( selected( $instance['orientation'], 'vertical', false ) ) {
				$follow_area = 'display:block;';
				$autohide_area = 'display:none;';
			} else {
				$follow_area = 'display:none;';
				$autohide_area = 'display:block;';
			}
			?>
			<p class="cart-follow-area" style="<?php echo $follow_area; ?>">
				<label for="<?php echo esc_attr( $this->get_field_id( 'cart_follow' ) ); ?>"><?php _e( 'DropShop Positioning', 'woocommerce-dropshop' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'cart_follow' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'cart_follow' ) ); ?>" class="widefat">
					<option value="no-follow" <?php selected( $instance['cart_follow'], 'no-follow' ); ?>><?php _e( 'fixed', 'woocommerce-dropshop' ); ?></option>
					<option value="follow" <?php selected( $instance['cart_follow'], 'follow' ); ?>><?php _e( 'dynamic', 'woocommerce-dropshop' ); ?></option>
				</select>
				<small><?php _e( 'For DropShop to remain fixed in the widget position choose fixed. If you would like dropShop to appear whenever you try to drop an item in, choose dynamic.', 'woocommerce-dropshop' ); ?></small>
				
			</p>

			<div class="autohide-area" style="<?php echo $autohide_area; ?>">
				<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'autohide' ) ); ?>"><?php _e( 'Auto Hide Cart', 'woocommerce-dropshop' ); ?>&nbsp;&nbsp;<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'autohide' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'autohide' ) ); ?>" value="on" <?php checked( $instance['autohide'], 'on' ); ?>></label><br />
				<small><?php _e( 'Turning this on will activate the cart to autohide after X seconds in the horizontal mode.', 'woocommerce-dropshop' ); ?></small>
				</p>

				<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'autohide_duration' ) ); ?>"><?php _e( 'Auto Hide Cart Duration', 'woocommerce-dropshop' ); ?></label>
				<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'autohide_duration' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'autohide_duration' ) ); ?>" value="<?php echo esc_attr( $instance['autohide_duration'] ); ?>" class="widefat" /><br />
				<small><?php _e( 'Set the duration in which you would like until the cart auto hides. Default is 10 seconds.', 'woocommerce-dropshop' ); ?></small>				
				</p>

				<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'autohide_default' ) ); ?>"><?php _e( 'Cart Default Position', 'woocommerce-dropshop' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'autohide_default' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'autohide_default' ) ); ?>" class="widefat">
					<option value="show" <?php selected( $instance['autohide_default'], 'show' ); ?>><?php _e( 'Show', 'woocommerce-dropshop' ); ?></option>
					<option value="hide" <?php selected( $instance['autohide_default'], 'hide' ); ?>><?php _e( 'Hide', 'woocommerce-dropshop' ); ?></option>
				</select>
				<small><?php _e( 'Choose if you would like the cart to be shown by default or hidden by default.', 'woocommerce-dropshop' ); ?></small>				
				</p>
			</div>  

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'visible' ) ); ?>"><?php _e( 'Show how many products?', 'woocommerce-dropshop' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'visible' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'visible' ) ); ?>" class="sp-woocommerce-dropshop-select widefat">
					<option value="1" <?php selected( $instance['visible'], 1 ); ?>>1</option>
					<option value="2" <?php selected( $instance['visible'], 2 ); ?>>2</option>
					<option value="3" <?php selected( $instance['visible'], 3 ); ?>>3</option>
					<option value="4" <?php selected( $instance['visible'], 4 ); ?>>4</option>
					<option value="5" <?php selected( $instance['visible'], 5 ); ?>>5</option>
					<option value="6" <?php selected( $instance['visible'], 6 ); ?>>6</option>
					<option value="7" <?php selected( $instance['visible'], 7 ); ?>>7</option>
				</select>
				<small><?php _e( 'Set the maximum number of products you want to display in the DropShop at one time', 'woocommerce-dropshop' ); ?></small>
				
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'show_item_count' ) ); ?>"><?php _e( 'Show Item Count', 'woocommerce-dropshop' ); ?>&nbsp;&nbsp;<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'show_item_count' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_item_count' ) ); ?>" value="on" <?php checked( $instance['show_item_count'], 'on' ); ?>></label><br />
				<small><?php _e( 'Turning this on will show the item count at the corner of the item image.', 'woocommerce-dropshop' ); ?></small>
				
			</p>  

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'show_product_title' ) ); ?>"><?php _e( 'Show Product Title on Hover', 'woocommerce-dropshop' ); ?>&nbsp;&nbsp;<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'show_product_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_product_title' ) ); ?>" value="on" <?php checked( $instance['show_product_title'], 'on' ); ?>></label><br />
				<small><?php _e( 'Turning this on will show the product title when cursor is hovered over the product in the cart.', 'woocommerce-dropshop' ); ?></small>
				
			</p> 

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'scrollby' ) ); ?>"><?php _e( 'Arrow clicks scroll by how many products?', 'woocommerce-dropshop' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'scrollby' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'scrollby' ) ); ?>" class="sp-woocommerce-dropshop-select widefat">
					<option value="1" <?php selected( $instance['scrollby'], 1 ); ?>>1</option>
					<option value="2" <?php selected( $instance['scrollby'], 2 ); ?>>2</option>
					<option value="3" <?php selected( $instance['scrollby'], 3 ); ?>>3</option>
					<option value="4" <?php selected( $instance['scrollby'], 4 ); ?>>4</option>
					<option value="5" <?php selected( $instance['scrollby'], 5 ); ?>>5</option>
					<option value="6" <?php selected( $instance['scrollby'], 6 ); ?>>6</option>
				</select>
				<small><?php _e( 'How many DropShop items should scroll each time you click the arrows?', 'woocommerce-dropshop' ); ?></small>
				
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'speed' ) ); ?>"><?php _e( 'Scroll Speed:', 'woocommerce-dropshop' ); ?></label>
				<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'speed' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'speed' ) ); ?>" value="<?php echo esc_attr( $instance['speed'] ); ?>" class="widefat" />
				<small><?php _e( 'How fast would you like the items to scroll when you click the arrows? 1000 is equal to 1 second.', 'woocommerce-dropshop' ); ?></small>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'easing' ) ); ?>"><?php _e( 'Easing Effect', 'woocommerce-dropshop' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'easing' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'easing' ) ); ?>" class="sp-woocommerce-dropshop-select widefat">
					<option value="swing" <?php selected( $instance['easing'], 'swing' ); ?>><?php _e( 'Swing', 'woocommerce-dropshop' ); ?></option>
					<option value="cubic" <?php selected( $instance['easing'], 'cubic' ); ?>><?php _e( 'Cubic', 'woocommerce-dropshop' ); ?></option>
					<option value="quadratic" <?php selected( $instance['easing'], 'quadratic' ); ?>><?php _e( 'Quadratic', 'woocommerce-dropshop' ); ?></option>
					<option value="elastic" <?php selected( $instance['easing'], 'elastic' ); ?>><?php _e( 'Elastic', 'woocommerce-dropshop' ); ?></option>
					<option value="linear" <?php selected( $instance['easing'], 'linear' ); ?>><?php _e( 'Linear', 'woocommerce-dropshop' ); ?></option>
				</select>
				<small><?php _e( 'Set the easing effect you want when scrolling through the DropShop items.', 'woocommerce-dropshop' ); ?></small>
				
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'show_on_single' ) ); ?>"><?php _e( 'Show Cart on Single Product Page', 'woocommerce-dropshop' ); ?>&nbsp;&nbsp;<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'show_on_single' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_on_single' ) ); ?>" value="on" <?php checked( $instance['show_on_single'], 'on' ); ?>></label><br />
				<small><?php _e( 'Turning this on will show drop shop cart on single products page.', 'woocommerce-dropshop' ); ?></small>	            
			</p>  

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'show_on_shop' ) ); ?>"><?php _e( 'Show Cart On Shop Pages Only', 'woocommerce-dropshop' ); ?>&nbsp;&nbsp;<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'show_on_shop' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_on_shop' ) ); ?>" value="on" <?php checked( $instance['show_on_shop'], 'on' ); ?>></label><br />
				<small><?php _e( 'Turning this on will show drop shop cart on only shop pages.', 'woocommerce-dropshop' ); ?></small>	            
			</p>  

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'exclude_pages' ) ); ?>"><?php _e( 'Exclude Pages', 'woocommerce-dropshop' ); ?></label>
				<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'exclude_pages' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'exclude_pages' ) ); ?>" value="<?php echo esc_attr( $instance['exclude_pages'] ); ?>" class="widefat" />
				<small><?php _e( 'This setting will hide the cart from the pages you specify.  You can enter a comma separated list of page ids.', 'woocommerce-dropshop' ); ?></small>
			</p>  

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'exclude_categories' ) ); ?>"><?php _e( 'Exclude Categories', 'woocommerce-dropshop' ); ?></label>
				<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'exclude_categories' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'exclude_categories' ) ); ?>" value="<?php echo esc_attr( $instance['exclude_categories'] ); ?>" class="widefat" />
				<small><?php _e( 'This setting will hide the cart from the categories you specify.  You can enter a comma separated list of category names.', 'woocommerce-dropshop' ); ?></small>
			</p>  
	
		</div><!--close sp-woocommerce-dropshop-col1-->
		<div class="sp-woocommerce-dropshop-col2">
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'theme' ) ); ?>"><?php _e( 'Preset Theme:', 'woocommerce-dropshop' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'theme' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'theme' ) ); ?>" class="widefat">
					<option value="light" <?php selected( $instance['theme'], 'light' ); ?>><?php _e( 'Light Theme', 'woocommerce-dropshop' ); ?></option>
					<option value="dark" <?php selected( $instance['theme'], 'dark' ); ?>><?php _e( 'Dark Theme', 'woocommerce-dropshop' ); ?></option>
				</select>
				<small><?php _e( 'You can further customize below or use as is.', 'woocommerce-dropshop' ); ?></small><br />
			</p>   

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'custom' ) ); ?>"><?php _e( 'Enable Custom Styles', 'woocommerce-dropshop' ); ?>&nbsp;
					<input type="checkbox" class="sp-woocommerce-dropshop-custom-option" id="<?php echo esc_attr( $this->get_field_id( 'custom' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'custom' ) ); ?>" <?php checked( $instance['custom'], 'on' ); ?>  value="on" />
				</label>
			</p>
			<?php 
			// check if custom options are enabled if so show area
			$custom_style = 'display:none;';
			if ( $instance['custom'] === 'on' ) 
				$custom_style = 'display:block;';
			?>
			<div class="sp-woocommerce-dropshop-option-area" style="<?php echo $custom_style; ?>"> 
				<h4 class="sp-woocommerce-dropshop-h4"><?php _e( 'Customizations:', 'woocommerce-dropshop' ); ?></h4>
				<p>
					<label for="<?php echo esc_attr( $this->get_field_id( 'cart_bg_color' ) ); ?>"><?php _e( 'DropShop Background Color:', 'woocommerce-dropshop' ); ?></label><br />
					<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'cart_bg_color' ) ); ?>" class="sp-woocommerce-dropshop-color-input" name="<?php echo esc_attr( $this->get_field_name( 'cart_bg_color' ) ); ?>" value="<?php echo esc_attr( $instance['cart_bg_color'] ); ?>" />
				</p>

				<p>
					<label for="<?php echo esc_attr( $this->get_field_id( 'inset_bg_color' ) ); ?>"><?php _e( 'DropShop Inset Background Color:', 'woocommerce-dropshop' ); ?></label><br />
					<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'inset_bg_color' ) ); ?>" class="sp-woocommerce-dropshop-color-input" name="<?php echo esc_attr( $this->get_field_name( 'inset_bg_color' ) ); ?>" value="<?php echo esc_attr( $instance['inset_bg_color'] ); ?>" />
				</p>

				<p>
					<label for="<?php echo esc_attr( $this->get_field_id( 'inset_corners' ) ); ?>"><?php _e( 'DropShop Inset Rounded Corners:', 'woocommerce-dropshop' ); ?>
						<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'inset_corners' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'inset_corners' ) ); ?>" <?php checked( $instance['inset_corners'], 'on' ); ?>  />
					</label><br />
					<small><?php _e( 'Check box to turn on rounded corners for your inset area.', 'woocommerce-dropshop' ); ?></small>
				</p>

				<p>
					<label for="<?php echo esc_attr( $this->get_field_id( 'inset_shadow' ) ); ?>"><?php _e( 'DropShop Inset Shadow:', 'woocommerce-dropshop' ); ?>
						<input type="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'inset_shadow' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'inset_shadow' ) ); ?>" <?php checked( $instance['inset_shadow'], 'on' ); ?>  />
					</label><br />
					<small><?php _e( 'Check box to show a inset shadow for your inset area.', 'woocommerce-dropshop' ); ?></small>
				</p>     

				<p>
					<label for="<?php echo esc_attr( $this->get_field_id( 'btn_bg_color' ) ); ?>"><?php _e( 'Buttons Background Color:', 'woocommerce-dropshop' ); ?></label><br />
					<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'btn_bg_color' ) ); ?>" class="sp-woocommerce-dropshop-color-input" name="<?php echo esc_attr( $this->get_field_name( 'btn_bg_color' ) ); ?>" value="<?php echo esc_attr( $instance['btn_bg_color'] ); ?>" />
				</p>

				<p>
					<label for="<?php echo esc_attr( $this->get_field_id( 'btn_bg_color_hv' ) ); ?>"><?php _e( 'Buttons Background Color on Hover:', 'woocommerce-dropshop' ); ?></label><br />
					<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'btn_bg_color_hv' ) ); ?>" class="sp-woocommerce-dropshop-color-input" name="<?php echo esc_attr( $this->get_field_name( 'btn_bg_color_hv' ) ); ?>" value="<?php echo esc_attr( $instance['btn_bg_color_hv'] ); ?>" />
				</p>

				<p>
					<label for="<?php echo esc_attr( $this->get_field_id( 'btn_text_color' ) ); ?>"><?php _e( 'Buttons Text Color:', 'woocommerce-dropshop' ); ?></label><br />
					<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'btn_text_color' ) ); ?>" class="sp-woocommerce-dropshop-color-input" name="<?php echo esc_attr( $this->get_field_name( 'btn_text_color' ) ); ?>" value="<?php echo esc_attr( $instance['btn_text_color'] ); ?>" />
				</p>  

				<p>
					<label for="<?php echo esc_attr( $this->get_field_id( 'font_style' ) ); ?>"><?php _e( 'Font Style:', 'woocommerce-dropshop' ); ?></label>
					<select id="<?php echo esc_attr( $this->get_field_id( 'font_style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'font_style' ) ); ?>" class="widefat">
						<option value="sans-serif" <?php selected( $instance['font_style'], 'sans-serif' ); ?>><?php _e( 'sans-serif', 'woocommerce-dropshop' ); ?></option>
						<option value="serif" <?php selected( $instance['font_style'], 'serif' ); ?>><?php _e( 'serif', 'woocommerce-dropshop' ); ?></option>
					</select>
					<small><?php _e( 'Choose a font family: Serif looks like Times New Roman and Courier.  Sans Serif looks like Arial and Helvetica.', 'woocommerce-dropshop' ); ?></small>
					
				</p>

				<p>
					<label for="<?php echo esc_attr( $this->get_field_id( 'text_color' ) ); ?>"><?php _e( 'DropShop Text Color:', 'woocommerce-dropshop' ); ?></label><br />
					<input type="text" id="<?php echo esc_attr( $this->get_field_id( 'text_color' ) ); ?>" class="sp-woocommerce-dropshop-color-input" name="<?php echo esc_attr( $this->get_field_name( 'text_color' ) ); ?>" value="<?php echo esc_attr( $instance['text_color'] ); ?>" />
				</p>

				<p>
					<label for="<?php echo esc_attr( $this->get_field_id( 'arrow_color' ) ); ?>"><?php _e( 'DropShop Prev/Next Arrow Color:', 'woocommerce-dropshop' ); ?></label>
					<select id="<?php echo esc_attr( $this->get_field_id( 'arrow_color' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'arrow_color' ) ); ?>" class="widefat">
						<option value="light" <?php selected( $instance['arrow_color'], 'light' ); ?>><?php _e( 'Light', 'woocommerce-dropshop' ); ?></option>
						<option value="neutral" <?php selected( $instance['arrow_color'], 'neutral' ); ?>><?php _e( 'Neutral', 'woocommerce-dropshop' ); ?></option>
						<option value="dark" <?php selected( $instance['arrow_color'], 'dark' ); ?>><?php _e( 'Dark', 'woocommerce-dropshop' ); ?></option>
					</select>
					<small><?php _e( 'Choose an arrow color that will work best with the colors chosen above.', 'woocommerce-dropshop' ); ?></small>
				</p>
			</div><!--close custom-options-->
		</div><!--close sp-woocommerce-dropshop-col2-->
		<div class="clear"></div>
		<?php
		
		return true;
	}

	/**
	 * this function loads the necessary backend scripts
	 *
	 * @access private
	 * @since 1.0
	 * @return boolean true
	 */
	public function wc_dropshop_backend_scripts() {
		// enqueue color picker
		wp_enqueue_script( 'wp-color-picker' );	

		// enqueue WP color picker styles
		wp_enqueue_style( 'wp-color-picker' );	

		// register and enqueue admin styles	
		wp_register_style( 'sp-woocommerce-dropshop-admin-styles', WC_DROPSHOP_URL . 'assets/css/admin.css', '', WC_DROPSHOP_VERSION );
		wp_enqueue_style( 'sp-woocommerce-dropshop-admin-styles' );

		// register and enqueue admin scripts
		wp_register_script( 'sp-woocommerce-dropshop-admin', WC_DROPSHOP_URL . 'assets/js/admin.js', '', WC_DROPSHOP_VERSION, true );    
		wp_enqueue_script( 'sp-woocommerce-dropshop-admin' );
		
		return true;
	}
}