<?php
/**
 * file that generates the HTML for the widget template
 *
 * @package WC_Dropshop
 *
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit; // no direct access
}

global $sp_woocommerce_dropshop_settings;

$tab_color = '';

// change image size based on dropshop orientation
if ( $sp_woocommerce_dropshop_settings['orientation'] === 'horizontal' ) {
	$cart_image_width = apply_filters( 'sp_woocommerce_dropshop_horizontal_item_image_width', 80 );
	$cart_image_height = apply_filters( 'sp_woocommerce_dropshop_horizontal_item_image_height', 80 );
	
	// check if custom is on
    if ( $sp_woocommerce_dropshop_settings['custom'] === 'on' ) {
		// check if tab background color is set
		if ( isset( $sp_woocommerce_dropshop_settings['cart_bg_color'] ) && $sp_woocommerce_dropshop_settings['cart_bg_color'] != '' ) { 
			$tab_color = 'background-color:' . $sp_woocommerce_dropshop_settings['cart_bg_color'] . ';';
		}
	}
	
} else {
	$cart_image_width = apply_filters( 'sp_woocommerce_dropshop_vertical_item_image_width', 150 );
	$cart_image_height = apply_filters( 'sp_woocommerce_dropshop_vertical_item_image_height', 120 );
}

?> 
	<div class="sp-woocommerce-dropshop-center group">
    <?php
	// apply custom tab background color
    if ( $sp_woocommerce_dropshop_settings['orientation'] === 'horizontal' ) {
	?>
    	<span class="sp-woocommerce-dropshop-tab" style="<?php echo $tab_color; ?>"><i class="<?php echo esc_attr( $sp_woocommerce_dropshop_settings['theme'] ); ?> sp-woocommerce-dropshop-cart-icon"></i></span> 
    <?php } ?>
	<div class="sp-woocommerce-dropshop-wrap group">
        <span class="sp-woocommerce-dropshop-top-divider">&nbsp;</span>
        <?php
        $style = '';
        $class = '';
        if ( $sp_woocommerce_dropshop_settings['custom'] === 'on' ) {
            // check if background color is set
            if ( isset( $sp_woocommerce_dropshop_settings['inset_bg_color'] ) && $sp_woocommerce_dropshop_settings['inset_bg_color'] != '' )
                $style .= 'background-image:none;background-color:' . $sp_woocommerce_dropshop_settings['inset_bg_color'] . ';'; 
            
            // check if shadow is turned on
            if ( isset( $sp_woocommerce_dropshop_settings['inset_shadow'] ) && $sp_woocommerce_dropshop_settings['inset_shadow'] != '' )
                $class .= 'inset-shadow';

            // check if rounded corners are turned on
            if ( isset( $sp_woocommerce_dropshop_settings['inset_corners'] ) && $sp_woocommerce_dropshop_settings['inset_corners'] != '' )
                $class .= ' inset-rounded';            
        }
        ?>
        <div class="sp-woocommerce-dropshop-inner group <?php echo esc_attr( $class ); ?>" style="<?php echo esc_attr( $style ); ?>">
            
            <span class="sp-woocommerce-dropshop-prev disabled"><i class="icon"></i></span>
            <?php if ( sizeof( WC()->cart->get_cart() ) > 0 ) { ?>
            <div id="sp-woocommerce-cart" class="group"> 
                <ul>
                    <?php foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) { 
                        $_product = $cart_item['data'];
                        if ( $_product->exists() && $cart_item['quantity'] > 0 ) {
                        ?>
                            <li class="draggable-cart-item cart_item_id_<?php echo esc_attr( $cart_item_key ); ?>" id="draggable-item-<?php echo esc_attr( $cart_item['product_id'] ); ?>">
                                <?php if ( WC()->cart->get_item_data( $cart_item ) ) { 
                                    $title = esc_attr( $_product->get_title() ) . " (" . strip_tags( WC()->cart->get_item_data( $cart_item, true ) ) . ")";
                                } else {
                                    $title = esc_attr( $_product->get_title() );
                                }

                                // check if show product title is on
                                if ( $sp_woocommerce_dropshop_settings['show_product_title'] === 'on' ) {
                                ?>
                                <a href="<?php echo get_permalink( $cart_item['product_id'] ); ?>" class="sp-tooltip" title="<?php echo esc_attr( $title ); ?>">
                                    <?php $image_url = WC_Dropshop()->frontend->get_cart_item_image( $cart_item['product_id'], $cart_item['variation_id'], $cart_image_width, $cart_image_height ); ?>

                                    <img src="<?php echo $image_url; ?>" class="sp-woocommerce-dropshop-cart-item" alt="<?php echo esc_attr( $_product->get_title() ); ?>" width="<?php echo esc_attr( $cart_image_width ); ?>" height="<?php echo esc_attr( $cart_image_height ); ?>" />
                                </a>
                                <?php
                                } else {
                                ?>
                                <a href="<?php echo get_permalink( $cart_item['product_id'] ); ?>" title="<?php echo esc_attr( $title ); ?>">
                                    <?php $image_url = WC_Dropshop()->frontend->get_cart_item_image( $cart_item['product_id'], $cart_item['variation_id'], $cart_image_width, $cart_image_height ); ?>

                                    <img src="<?php echo $image_url; ?>" class="sp-woocommerce-dropshop-cart-item" alt="<?php echo esc_attr( $_product->get_title() ); ?>" width="<?php echo esc_attr( $cart_image_width ); ?>" height="<?php echo esc_attr( $cart_image_height ); ?>" />

                                </a>
                                <?php
                                }
                                ?>
                                
                                <form id="draggable-item-<?php echo esc_attr( $cart_item['product_id'] ); ?>-form" method="post" action="<?php the_permalink(); ?>" >
                                    <input type="hidden" value="<?php echo esc_attr( $cart_item['product_id'] ); ?>" name="product_id" />
                                    <input type="hidden" value="<?php echo esc_attr( $cart_item_key ); ?>" name="cart_id" />
                                    <input type="hidden" value="<?php echo esc_attr( $cart_item['quantity'] ); ?>" name="quantity" />
                                    <input type="hidden" value="<?php echo esc_attr( $cart_item['variation_id'] ); ?>" name="variation_id" />
                                </form>

                                <?php
                                // check if we need to show the item quantity
                                if ( $sp_woocommerce_dropshop_settings['show_item_count'] === 'on' ) {
                                ?>
                                    <span class="sp-woocommerce-dropshop-item-count"><?php echo $cart_item['quantity']; ?></span>
                                <?php
                                }
                                ?>
                                <a href="#" title="<?php esc_attr_e( 'Remove Item', 'woocommerce-dropshop' ); ?>" class="sp-woocommerce-dropshop-item-remover"><i class="icon"></i></a>
                            </li>
                    <?php } 
                        } ?>
                </ul>        
            </div><!--close sp-woocommerce-cart-->
            <?php } else { ?>
                <p class="sp-woocommerce-dropshop-cart-empty">
                <?php
    			if ( $sp_woocommerce_dropshop_settings['orientation'] === 'horizontal' ) { ?>
    				<span><?php apply_filters( 'sp_woocommerce_dropshop_empty_cart_text', _e( 'drop items here', 'woocommerce-dropshop' ) ); ?></span>
    				<i class="sp-woocommerce-dropshop-cart-empty-icon"></i>
                <?php
    			} else {
    				 apply_filters( 'sp_woocommerce_dropshop_empty_cart_text', _e( 'drop items here', 'woocommerce-dropshop' ) ); ?><br />
                    <i class="sp-woocommerce-dropshop-cart-empty-icon"></i>
                <?php } ?>
                </p>
            <?php } // end check if have items ?>
            <span class="sp-woocommerce-dropshop-next disabled"><i class="icon"></i></span>
            
            <img src="<?php echo WC_DROPSHOP_URL . 'assets/images/drop_spinner.gif'; ?>" alt="<?php esc_attr_e( 'Load Spinner', 'woocommerce-dropshop' ); ?>" class="sp-woocommerce-dropshop-dragdrop-spinner" />
        </div><!--close sp-woocommerce-dropshop-inner-->  
        <span class="sp-woocommerce-dropshop-bottom-divider">&nbsp;</span>
        <div class="sp-woocommerce-dropshop-meta group">
        <p class="sp-woocommerce-dropshop-cart-total"><?php apply_filters( 'sp_woocommerce_dropshop_subtotal_text', _e( 'Sub-Total:', 'woocommerce-dropshop' ) ); ?> <?php echo WC()->cart->get_cart_subtotal(); ?></p>
        <?php
            $style = '';
            // check if custom is on
            if ( $sp_woocommerce_dropshop_settings['custom'] == 'on' ) {
                $btn_bg_color = $sp_woocommerce_dropshop_settings['btn_bg_color'];
                $btn_text_color = $sp_woocommerce_dropshop_settings['btn_text_color'];
                
                // check if checkout button is set
                if ( isset( $btn_bg_color ) && $btn_bg_color != '' )
                    $style .= 'background-image:none;background-color:' . $btn_bg_color . ';';	
                    
                if ( isset( $btn_text_color ) && $btn_text_color != '' )
                    $style .= 'color:' . $btn_text_color . ';';
            }
        ?>
        <a href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" title="<?php apply_filters( 'sp_woocommerce_dropshop_view_cart_text', esc_attr_e( 'View Cart', 'woocommerce-dropshop' ) ); ?>" class="sp-woocommerce-dropshop-viewcart-button" style="<?php echo esc_attr( $style ); ?>"><?php apply_filters( 'sp_woocommerce_dropshop_view_cart_text', _e( 'View Cart', 'woocommerce-dropshop' ) ); ?></a> 
        <a href="<?php echo esc_url( WC()->cart->get_checkout_url() ); ?>" title="<?php apply_filters( 'sp_woocommerce_dropshop_checkout_button_text', esc_attr_e( 'Checkout', 'woocommerce-dropshop' ) ); ?>" class="sp-woocommerce-dropshop-checkout-button" style="<?php echo esc_attr( $style ); ?>"><?php apply_filters( 'sp_woocommerce_dropshop_checkout_button_text', _e( 'Checkout', 'woocommerce-dropshop' ) ); ?></a> 
        </div><!--close sp-woocommerce-dropshop-meta-->  
	</div><!--close sp-woocommerce-dropshop-wrap-->
</div><!--close sp-woocommerce-dropshop-center-->
<?php echo '<input type="hidden" class="sp-woocommerce-dropshop-settings" name="sp_woocommerce_dropshop_settings" value="' . esc_attr( json_encode( $sp_woocommerce_dropshop_settings ) ) . '" />' . PHP_EOL; ?>