<?php
/*
Plugin Name: WooCommerce Drag N Drop Shop (Share on 20script.ir)
Plugin URI: http://www.20script.ir
Description: Adds a drag and drop cart widget to your sidebars for easier and faster purchases. To customize and add to sidebars, go to your <a title="WordPress Widgets settings" href="widgets.php">widget settings</a>
Author: Splashing Pixels (Roy Ho)
Author URI: http://www.20script.ir
Version: 2.0.0
License: GPLv3
*/

/*  Copyright 2013  Roy Ho  (email : roy@splashingpixels.com)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License, version 3, as 
	published by the Free Software Foundation.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

if ( ! defined( 'ABSPATH' ) ) { 
	exit; // no direct access
}

define( 'WC_DROPSHOP_URL', trailingslashit( plugins_url( '', __FILE__ ) ) );
define( 'WC_DROPSHOP_PATH', plugin_dir_path( __FILE__ ) );
define( 'WC_DROPSHOP_VERSION', '2.0.0' );

/**
 * Required functions
 */
if ( ! function_exists( 'woothemes_queue_update' ) ) {
	require_once( 'woo-includes/woo-functions.php' );
}

if ( ! class_exists( 'WC_Dropshop' ) ) :

final class WC_Dropshop {
	public $frontend = null;
	
	/**
	 * init
	 *
	 * @access public
	 * @since 2.0.0
	 * @return bool
	 */
	protected function __construct() {
		
		add_action( 'init', array( $this, 'load_plugin_textdomain' ) );

		if ( is_woocommerce_active() ) {

			// adds our widget to hook
			add_action( 'widgets_init', array( $this, 'woocommerce_dropshop_widget' ) );

			include_once( 'includes/class-wc-dropshop-frontend-ajax.php' );

			include_once( 'includes/class-wc-dropshop-frontend.php' );

			$this->frontend = new WC_Dropshop_Frontend();

		} else {
			add_action( 'admin_notices', array( $this, 'woocommerce_missing_notice' ) );
		}

		return true;
	}

	/**
	 * returns the singleton pattern of this class
	 *
	 * @since 1.3.0
	 * @return bool
	 */
	public static function get_instance() {
		static $instance = null;

		if ( null === $instance ) {
			$instance = new static();
		}

		return $instance;
	}

	/**
	 * private clone method to prevent cloning of the instance of the singleton
	 *
	 * @access private
	 * @since 1.3.0
	 * @return void
	 */
	private function __clone() {
		return void;
	}

	/**
	 * private unserialize method to prevent unserializing of the *Singleton* instance.
	 *
	 * @access private
	 * @since 1.3.0
	 * @return void
	 */
	private function __wakeup() {
		return void;
	}

	/**
	 * load the plugin text domain for translation.
	 *
	 * @since 1.0.0
	 * @return bool
	 */
	public function load_plugin_textdomain() {
		$locale = apply_filters( 'wc_dropshop_plugin_locale', get_locale(), 'woocommerce-dropshop' );

		load_textdomain( 'woocommerce-dropshop', trailingslashit( WP_LANG_DIR ) . 'woocommerce-dropshop' . '/' . 'woocommerce-dropshop' . '-' . $locale . '.mo' );

		load_plugin_textdomain( 'woocommerce-dropshop', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );

		return true;
	}

	/**
	 * WooCommerce fallback notice.
	 *
	 * @return string
	 */
	public function woocommerce_missing_notice() {
		echo '<div class="error"><p>' . sprintf( __( 'WooCommerce Drag N Drop Shop Plugin requires WooCommerce to be installed and active.', 'woocommerce-dropshop' ), '<a href="http://www.woothemes.com/woocommerce/" target="_blank">WooCommerce</a>' ) . '</p></div>';
	}

	/**
	 * load the widget
	 *
	 * @since 2.0.0
	 * @return bool
	 */
	public function woocommerce_dropshop_widget() {
		include_once( WC_DROPSHOP_PATH . 'includes/class-wc-dropshop-widget.php' );

		register_widget( 'WC_Dropshop_Widget' );

		return true;
	}
}

add_action( 'plugins_loaded', 'WC_Dropshop', 0 );

/**
 * init function
 *
 * @package WC_Dropshop
 * @since 2.0.0
 * @return bool
 */
function WC_Dropshop() {
	return WC_Dropshop::get_instance();
}

endif;
